@@ -1,6 +1,6 @@
 # File::Data into cvs
 # Copyright 2000 2001 Richard Foley richard.foley@rfi.net
-# $Id: Data.pm,v 1.4 2001/12/03 20:06:05 richard Exp $
+# $Id: Data.pm,v 1.5 2001/12/03 21:50:27 richard Exp $
 #
 
 package File::Data;           
@@ -10,7 +10,7 @@ use Data::Dumper;
 use FileHandle;
 # use File::stat;
 use vars qw(@ISA $VERSION $AUTOLOAD);
-$VERSION = do { my @r = (q$Revision: 1.4 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; 
+$VERSION = do { my @r = (q$Revision: 1.5 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; 
 $| = 1;
 
 =head1 NAME
@@ -1276,9 +1276,9 @@ sub _close {
 	my $i_ok = 0;
 
 	if ($FH) {
-		if ($FH->islocked) {
-			$self->_unlock;
-		}
+		#if ($FH->islocked) {
+		#	$self->_unlock;
+		#}
 		if ($FH->close) {
 			$i_ok++;
 		} else {
